// --- [ main.c ] --------------------------------------------------------------
//       tab = 3
//
//      Temperaturmessung mit 1-Wire-Bus / Sensoren DS18B20 
//
//      Die Sensoren sind nicht ber einen Bus sondern einzeln an Pins des Controllers
//      angeschlossen.
//      Es sind zwei Ports definierbar, an denen Sensoren angeschlossen werden knnen.
//      Jeder DQ-Pin bentigt einen Pullup nach VCC.
//
//      Wird nur 1 Port bentigt, dann sollte die schlankere Variante "owi_lib_sx"
//      benutzt werden !
//
//      Der Vorteil dieser Lsung:
//      Es knnen bis zu 16 Sensoren angeschlossen werden. 
//      Die ROM-Codes der Sensoren mssen nicht bekannt sein.
//      Jeder Sensor wird einzeln und nacheinder mit einem "SKIP ROM" angesprochen
//      und anschlieend die Temperatur ausgelesen.
//      Das funktioniert deshalb, weil nie mehr als 1 Sensor an jedem Pin angeschlossen ist.
//      
// ----------------------------------------------------------------------------

#define EXTERN

#include <avr/io.h>
#include <avr/interrupt.h>
#include <inttypes.h>
#include <stdlib.h>
#include <util/delay.h>
#include <stdio.h>
#include "rs232_mini.h"
#include "owi_lib_sx2.h"
#include "global.h"
#include "utility.h"

void read_port(uint8_t pin_mask, uint8_t port);

// ----------------------------------------------------------------------------
int main(void)
{

// --- die Serielle Schnittstelle aktivieren
RS232_Init();
put_c(13);

#if ONE_WIRE_PIN_MASK_1 > 0
	ONE_WIRE_PORT_1_CONFIG; 					// DQ_1_Pins 
	put_s("PinMaske1: 0x");
	put_s(utoa(ONE_WIRE_PIN_MASK_1, cv, 16));
	put_c(13);
#endif

#if ONE_WIRE_PIN_MASK_2 > 0
	ONE_WIRE_PORT_2_CONFIG; 					// DQ_2_Pins
  	put_s("PinMaske2: 0x");
	put_s(utoa(ONE_WIRE_PIN_MASK_2, cv, 16));
	put_c(13);
#endif
put_c(13);

while(1)												// Hauptschleife
	{

#if ONE_WIRE_PIN_MASK_1 > 0					// an alle Sensoren an Port1 ein CONVERT senden
	OW_convert(ONE_WIRE_PIN_MASK_1, DQ_PORT1);
#endif
#if ONE_WIRE_PIN_MASK_2 > 0					// an alle Sensoren an Port2 ein CONVERT senden
	OW_convert(ONE_WIRE_PIN_MASK_2, DQ_PORT2);
#endif

	delay_10ms(80);								// 800ms warten

#if ONE_WIRE_PIN_MASK_1 > 0	
	read_port(ONE_WIRE_PIN_MASK_1, DQ_PORT1);
#endif	

#if ONE_WIRE_PIN_MASK_2 > 0	
	read_port(ONE_WIRE_PIN_MASK_2, DQ_PORT2);
#endif
	
	put_c(13);
	delay_10ms(200);								// 2 Sekunden Wartezeit

	}
}

// ----------------------------------------------------------------------------
// liest alle Messwerte an den maskierten Pins des angebenen Ports aus
// und druckt die Werte via serieller Schnittstelle
void read_port(uint8_t pin_mask, uint8_t port)
{
	uint8_t i, sensor_mask;
	int16_t tt;
	
	put_s("Port");
	put_s(utoa((port + 1), cv, 10));
	put_s(": ");
	sensor_mask = 1;					
	for(i = 0; i < 8; i++)						// Alle 8 Pins abfragen
	{
		if (pin_mask & sensor_mask)// aber nur dann, wenn der Pin als Anschluss fr DQ definiert ist  
		{
			tt = DS18B20_read(sensor_mask, port);	// Wert als int16 abholen
			itoa(tt, cv, 10);						// in einen String umwandeln
			Make_Dez_Point1();					// einen Dezimalpunkt einschmuggeln
			put_s(cv);								// den String ausgeben
			put_c(DELIMITER);
		}	
		sensor_mask *= 2;							// Maskierten Pin weiterschieben
	}
	put_c(13);
}

// --- [ eof ] ----------------------------------------------------------------