// --- [owi_lib_sx2.h ] -----------------------------------------------------------
//
//      Lib zum ansprechen von mehreren Sensoren, bei denen jeweils der DQ-Pin
//      an einem eigenen Portpin angeschlossen ist.
//      Es knnen zwei Ports definiert werden, an denen Sensoren angeschlossen werden.
//      Sobald mindestens 1 Pin als Anschluss definiert ist, wird der Port beim Kompilieren
//      eingebunden.

// --- Den ersten Port und die benutzten Pins definieren -----------------------

#define ONE_WIRE_PORT_1			PORTB		// Hier den 1. Port fr die DQ-Pins festlegen
#define ONE_WIRE_PIN_1			PINB
#define ONE_WIRE_DDR_1			DDRB
													// Festlegen, welche Pins an Port1 benutzt werden sollen
#define ONE_WIRE_PIN_MASK_1	(0<<PB7 | 0<<PB6 | 0<<PB5 | 0<<PB4 | 0<<PB3 | 1<<PB2 | 1<<PB1 | 0<<PB0)

// --- Den zweiten Port und die benutzten Pins definieren -----------------------

#define ONE_WIRE_PORT_2			PORTC		// Hier den 2. Port fr die DQ-Pins festlegen
#define ONE_WIRE_PIN_2			PINC
#define ONE_WIRE_DDR_2			DDRC
													// Festlegen, welche Pins an Port2 benutzt werden sollen
													// PC6 = Reset, PC7 gibt am ATMegax8 nicht !
#define ONE_WIRE_PIN_MASK_2	(1<<PC5 | 1<<PC4 | 0<<PC3 | 0<<PC2 | 0<<PC1 | 0<<PC0)

// --- ab hier sind keine Anpassungen mehr erforderlich !! ----------------------

// Die Pins fr Port1 als Ausgang schalten und auf HIGH legen
#define ONE_WIRE_PORT_1_CONFIG 	(ONE_WIRE_DDR_1  |= ONE_WIRE_PIN_MASK_1); \
											(ONE_WIRE_PORT_1 |= ONE_WIRE_PIN_MASK_1)

// Die Pins fr Port2 als Ausgang schalten und auf HIGH legen
#define ONE_WIRE_PORT_2_CONFIG	(ONE_WIRE_DDR_2  |= ONE_WIRE_PIN_MASK_2); \
											(ONE_WIRE_PORT_2 |= ONE_WIRE_PIN_MASK_2)

#define DQ_1_LOW				ONE_WIRE_PORT_1 &= ~(ow_pin_mask)
#define DQ_1_HIGH				ONE_WIRE_PORT_1 |=  (ow_pin_mask)
#define DQ_1_OUTPUT			ONE_WIRE_DDR_1  |=  (ow_pin_mask)
#define DQ_1_INPUT			ONE_WIRE_DDR_1  &= ~(ow_pin_mask)
#define DQ_1_READ				ONE_WIRE_PIN_1  &   (ow_pin_mask)

#define DQ_2_LOW				ONE_WIRE_PORT_2 &= ~(ow_pin_mask)
#define DQ_2_HIGH				ONE_WIRE_PORT_2 |=  (ow_pin_mask)
#define DQ_2_OUTPUT			ONE_WIRE_DDR_2  |=  (ow_pin_mask)
#define DQ_2_INPUT			ONE_WIRE_DDR_2  &= ~(ow_pin_mask)
#define DQ_2_READ				ONE_WIRE_PIN_2  &   (ow_pin_mask)

#define DQ_PORT1					0		// Es sind nur 0 und 1 zulssig !!!
#define DQ_PORT2					1		// da nur auf if(DQ_PORT) getestet wird.

#define SEARCH_ROM			0xF0
#define READ_ROM				0x33
#define MATCH_ROM				0x55
#define SKIP_ROM				0xCC
#define ALARM_SEARCH			0xEC
#define CONVERT				0x44
#define WRITE_SCRATCHPAD	0x4E
#define READ_SCRATCHPAD		0xBE
#define COPY_SCRATCHPAD		0x48
#define RECALL_E				0xB8
#define READ_POWER_SUPPLY	0xB4

#define DS18B20				0x28			// Family-Code fr DS18B20

#define DELAY_A				6				// Wartezeiten gem. APP-NOTE 126, Page 2-3
#define DELAY_B				64				// fr Standard Speed
#define DELAY_C				60
#define DELAY_D				10
#define DELAY_E				9
#define DELAY_F				55
#define DELAY_G				1				// anstelle 0
#define DELAY_H				480
#define DELAY_I				70
#define DELAY_J				410

// --- public Funktionen ------------------------------------------------------

void    OW_convert(uint8_t mask, uint8_t port);
int16_t DS18B20_read(uint8_t mask, uint8_t port);

// --- [ eof ] ----------------------------------------------------------------